function spikesout = Andrzejak_PRE_90_062906_AddSpikeNoise(spikesin,noiselevel)
% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying our manuscript.
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
%
% +++ What this particular script does:
%
%Superimpose the spiketrain with noise. See page 2, right column middle.
%
%
% ++++ Input ++++
%
% spikesin: original spiketrain
%
% noiselevel: level of noise (gamma in the manuscript). Range of possible values: [0,100]
% noiselevel=0 leaves the spiketrain unaffected
%
% ++++ Output ++++
%
% spikesout: noisy spike train
% 
spikecount = size(spikesin,2);
nout = round(noiselevel/100*spikecount); 
spikesout = spikesin;
rmindex = randperm(spikecount);
rmindex = rmindex(1:spikecount-nout);
spikesout = spikesout(rmindex);
spikesD = rand(1,nout);
spikesout = sort([spikesout spikesD]);
% First spike(s) and last spikes(s) might have been removed.
% Therefore, we scale again into the interval [0,1]
spikesout = spikesout-min(spikesout);    % first spike will be at 0
spikesout = spikesout/max(spikesout);    % last spikes will be at 1

