function S=Andrzejak_PRE_90_062906_CALL(systemtype,distancetype,NumberSpikes,noiselevel,UseRandomShuffle,q,s,k,h,w,verbose)
% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying the manuscript:
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
%
% +++ What this particular script does:
%
% This is main script. Using it you should be able to reproduce our figure 1a-e
%
% ++++ Input ++++
% Systemtype
%   case 1: model A
%   case 2: model B
%   case 3: model C
%   case 4: model D
%   case 5: model E
%
% distancetype, select spike train distance
%  case 1: SPIKE
%  case 2: ISI
%
% NumberSpikes: Number of spikes for the analysis, they will always be
% scaled into the time interval [0, 1]
%
% noiselevel: level of noise (gamma in the manuscript). Range of possible values: [0,100]
%
% UseRandomShuffle
%  case 1: original spike train is used.
%  case 2: random shuffle of spike train is used.
%
% q,s,k,h,w: as in the manuscript
%
% verbose:
%  case 0: no screen output
%  case 1: some screen output
%
% ++++ Output ++++
% S: The measure S, Equation (1) in the manuscript

[spikes]= Andrzejak_PRE_90_062906_GenerateSpikes(systemtype,NumberSpikes,verbose);
if verbose
    fprintf('Generated %i spikes \n',length(spikes));
end
noisyspikes = Andrzejak_PRE_90_062906_AddSpikeNoise(spikes,noiselevel);
if verbose
    fprintf('Added %i percent of noise\n',round(noiselevel));
end

if UseRandomShuffle
    ints = diff(noisyspikes);
    noisyspikes=[0 cumsum((ints(randperm(length(ints)))))];
    if verbose
        fprintf('Replaced the spike train with a random shuffle\n');
    end
end

if verbose
    fprintf('Starting calculation of the measure S\n');
    fprintf('Please be patient...(Computation time is high for small values the paramter s)\n');    
end
S = Andrzejak_PRE_90_062906_MeasureS(noisyspikes,distancetype,q,s,k,h,w,verbose);
if verbose
    fprintf('Done. S = %0.4f\n',S);
end



