function [spiketimes, spikecount] = Andrzejak_PRE_90_062906_DetectSpikesThreshold(x,threshold)
% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying the manuscript:
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
% +++ What this particular script does:
%
% This function detects the spikes using the upward-threshold-crossing technique.
% see page 2, right column, top
% The first spike will not be positioned at zero, but this will be achieved
% by the scaling outside this function

N = length(x);
spikecount =0;
spiketimes =zeros(1,N);

isbelow = x(1) < threshold;
for cn = 1:N
    if x(cn) > threshold
        if isbelow
            spikecount = spikecount+1;
            spiketimes(spikecount) = cn;
            isbelow = 0;
        end
    else
      isbelow = 1;  
    end    
end
spiketimes = spiketimes(spiketimes>0);%discard the zeros at the end of the array (which are a left over from the allocation above
