function S = Andrzejak_PRE_90_062906_MeasureS(x,distancetype,q,s,k,h,w,verbose)
% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying the manuscript:
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
% +++ What this particular script does:
%
% This is the most important script. It calculates the rank-based nonlinear
% predictability score for spike trains S
%
% ++++ Input ++++
%
% x: the spiketrain, 
% The function expects the times of spikes scaled between 0 (first spike)
% and 1 (last spike)
%
% distancetype, select spike train distance
%  case 1: SPIKE
%  case 2: ISI
%
% q,s,k,h,w: as in the manuscript
%
% verbose:
%  case 0: no screen output
%  case 1: some screen output
%
% ++++ Output ++++
% S: The measure S, Equation (1) in the manuscript
%
if verbose
    switch distancetype
        case 1
            fprintf('Using SPIKE distance\n');
        case 2
            fprintf('Using ISI distance\n');
    end
end

W = w/s+1;
NeffA=fix((1-q)/(s)+1);

Ncorrected = zeros(1,NeffA);
Ncorrected(1:NeffA) = NeffA-(W*2+1);
for counter = 1:W
    Ncorrected(counter) = NeffA-W-(counter);
    Ncorrected(NeffA-counter+1) = NeffA-W-(counter);
end;

distances1a =Andrzejak_PRE_90_062906_MatrixDij(x',0,1,q,s,W,1,distancetype,verbose);

distances1 = distances1a;
[~, indexes1] = sort(distances1);
ranks =zeros(NeffA,NeffA,'uint16');
N1 = 1:NeffA;
for si = 1:NeffA
    ranks(indexes1(:,si),si) = N1;
end


H = h/s;
NeffB = NeffA-H;
[~, indexes1] = sort(distances1(1:NeffB,1:NeffB));
NPEr = zeros(NeffB,1);
for j =1:NeffB
    NPEr(j) = ((Ncorrected(j)+1)/2-sum(ranks(indexes1(1:k,j)+H,j+H))/k)/((Ncorrected(j)+1)/2-(k+1)/2);
end;
S = mean(NPEr);








