% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying the manuscript:
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
%
% This particular script was used for our Phys. Rev. E. 90, 062906. 
% It orginiates from the SPIKY project. 
%
% More information can be found under
% "http://www.fi.isc.cnr.it/users/thomas.kreuz/Source-Code/SPIKY.html" and/or in
%
% Kreuz T, Chicharro D, Houghton C, Andrzejak RG, Mormann F: Monitoring spike train synchrony. J Neurophysiol 109, 1457 (2013)
% Kreuz T: SPIKE-distance. Scholarpedia 7(12):30652 (2012).
% Kreuz T: Measures of spike train synchrony. Scholarpedia, 6(10):11934 (2011).
% Kreuz T, Chicharro D, Greschner M, Andrzejak RG: Time-resolved and time-scale adaptive measures of spike train synchrony. J Neurosci Methods 195, 92 (2011).
% Kreuz T, Chicharro D, Andrzejak RG, Haas JS, Abarbanel HDI: Measuring multiple spike train synchrony. J Neurosci Methods 183, 287 (2009).
% Kreuz T, Haas JS, Morelli A, Abarbanel HDI, Politi A: Measuring spike train synchrony. J Neurosci Methods 165, 151 (2007)
%
% For questions and comments please contact us at "thomaskreuz (at) cnr.it".
%
% This function is called from SPIKY_calculate_distances_MEX to sort the subplots
% selected in the 'Selection: Measures' panel. It also eliminates empty subplots.
%
% Input:
% fx: cumulative ISI-values (one value more than number of ISIs)
% fy: for piecewise constant: one value for each ISI
%     for piecewise linear: two values for each ISI

function ave=SPIKY_f_selective_averaging(fx,fy,wmin,wmax)

num_isi=length(fx)-1;
if wmax>wmin
    if size(fy,2)==num_isi    % piecewise constant (e.g. ISI)
        first_winspike_ind=find(fx>wmin,1,'first');   % index of first spike after start of interval
        last_winspike_ind=find(fx<wmax,1,'last');     % index of last spike before end of interval
        if ~isempty(first_winspike_ind) && ~isempty(last_winspike_ind)
            if first_winspike_ind==1 && last_winspike_ind==length(fx)
                wmin=fx(1);
                wmax=fx(end);
            end
            if first_winspike_ind<=last_winspike_ind
                dfx=fx(first_winspike_ind:last_winspike_ind);
                dfy=fy(:,first_winspike_ind:last_winspike_ind-1);
                if wmin<dfx(1)              % interval to first spike
                    dfx=[wmin dfx];
                    dfy=[fy(:,first_winspike_ind-1) dfy];
                end
                if wmax>dfx(end)            % interval after last spike
                    dfx=[dfx wmax];
                    dfy=[dfy fy(:,last_winspike_ind)];
                end
                win_isi=diff(dfx);
                ave=sum(dfy.*repmat(win_isi,size(fy,1),1),2)/sum(win_isi);
            else
                ave=fy(:,last_winspike_ind);
            end
        end
    elseif size(fy,2)==num_isi*2    % piecewise linear (e.g. SPIKE)
        first_winspike_ind=find(fx>wmin,1,'first');   % index of first spike after start of interval
        last_winspike_ind=find(fx<wmax,1,'last');     % index of last spike before end of interval
        if ~isempty(first_winspike_ind) && ~isempty(last_winspike_ind)
            if first_winspike_ind==1 && last_winspike_ind==length(fx)
                wmin=fx(1);
                wmax=fx(end);
            end
            if first_winspike_ind<=last_winspike_ind
                dfx=fx(first_winspike_ind:last_winspike_ind);
                dfy=fy(:,max([1 (first_winspike_ind-1)*2]):min([num_isi*2 last_winspike_ind*2-1]));
                if wmin<dfx(1)              % interval to first spike
                    dfx=[wmin dfx];
                    dfy=[interp1(fx(first_winspike_ind-[1 0]),fy(:,first_winspike_ind*2-([3 2]))',wmin)' dfy];
                end
                if wmax>dfx(end)            % interval after last spike
                    dfx=[dfx wmax];
                    dfy=[dfy interp1(fx(last_winspike_ind+[0 1]),fy(:,last_winspike_ind*2-[1 0])',wmax)'];
                end
                win_isi=diff(dfx);
                odds=1:2:size(dfy,2);
                evens=odds+1;
                ave=sum((dfy(:,odds)+dfy(:,evens))/2.*repmat(win_isi,size(fy,1),1),2)/sum(win_isi);
            else
                ave=fy(:,last_winspike_ind);
            end
        end
    end
else
    ave=zeros(size(fy,1),1);
end
